Welcome to Scapy’s documentation! — kamene 3.0.0 documentation

# Welcome to Scapy’s documentation!

Release: | 3.0.0
Date: | May 27, 2018

This document is under a Creative Commons Attribution - Non-Commercial - Share Alike 2.5 license.

The document is under review to update from scapy to kamene. Some code samples may not work directly with kamene - usually change of str() to bytes() or ‘some string’ to b’some string’ fixes the problem.

- Introduction
  - About Scapy
  - What makes Scapy so special
  - Quick demo
  - Learning Python
- Download and Installation
  - Overview
  - Installing kamene
  - Optional software for special features
  - Platform-specific instructions
- Usage
  - Starting Scapy
  - Interactive tutorial
  - Simple one-liners
  - Recipes
- Advanced usage
  - ASN.1 and SNMP
  - Automata
- Automotive usage
  - Setup
  - Examples
- Build your own tools
  - Using Scapy in your tools
  - Extending Scapy with add-ons
- Adding new protocols
  - Simple example
  - Layers
  - Dissecting
  - Building
  - Fields
- Troubleshooting
  - FAQ
  - Getting help
- Scapy development
  - Project organization
  - How to contribute
  - Testing with UTScapy
- Credits